from os import path, makedirs
import cassiopeia as cass

# Folders utilities
base_folder = path.join(path.expanduser("~"), '.config', 'ezreal')
token_location = path.join(base_folder, 'riotapi_token.txt')

if not path.exists(base_folder):
    makedirs(base_folder)


# Riot API token acquisition
def setup_riotapi_token():
    try:
        with open(token_location) as file:
            riotapi_token = file.read()
    except FileNotFoundError:
        print(f'Riot API token not found\n'
              f'If you don’t have one, you can create it at https://developer.riotgames.com/\n'
              f'It will be saved in clear text at {path.join(base_folder, "riotapi_token.txt")}\n'
              f'Please input the Riot API token:')
        riotapi_token = input()
        with open(token_location, 'w+') as file:
            file.write(riotapi_token)
    cass.set_riot_api_key(riotapi_token)


import cassiopeia as cass
from cassiopeia import Summoner
from ezreal.utils import engine
from ezreal.core.summoner import get_summoner_info


def print_summoner(name: str, region: str):
    summoner = get_summoner_info(name, region)
    print("Name:", summoner.name)
    print("ID:", summoner.id)
    print("Account ID:", summoner.account_id)
    print("Level:", summoner.level)
    print("Revision date:", summoner.revision_date)
    print("Profile icon ID:", summoner.profile_icon.id)
    print("Profile icon name:", summoner.profile_icon.name)
    print("Profile icon URL:", summoner.profile_icon.url)
    print("Profile icon image:", summoner.profile_icon.image)
    return summoner


if __name__ == "__main__":
    summoner = print_summoner("Kassout", "EUW")
    # print(summoner)


import configparser
from os import path
from getpass import getpass, getuser
import sqlalchemy
from sqlalchemy import orm
from sqlalchemy.ext import declarative

from ezreal.utils import base_folder

config_location = path.join(base_folder, 'db_config.ini')
db_config = configparser.ConfigParser()

Base = declarative.declarative_base()

# Opening the database
try:
    with open(config_location) as configfile:
        db_config.read_file(configfile)
except FileNotFoundError:
    print(f'Database config file not found. No database configured.\n'
          f'This program is able to setup a database starting kit in SQLite.\n'
          f'You can also choose to use a postgresql databse and configure its access by following.\n'
          f'It will be saved in clear text at {path.join(base_folder, "db_config.ini")}\n'
          f'Please input your db choice: [postgresql/sqlite]')
    db_choice = input()
    db_config['general'] = {}
    if db_choice == 'sqlite':
        db_config['general']['db_type'] = db_choice
        print(f'SQLite database setup complete.')
    elif db_choice == 'postgresql':
        db_config['general']['db_type'] = db_choice
        db_config['connection_info'] = {}
        print(f'username:')
        db_config['connection_info']['username'] = getuser()
        print(f'password:')
        db_config['connection_info']['password'] = getpass()
        print(f'host:')
        db_config['connection_info']['host'] = input()
        print(f'port:')
        db_config['connection_info']['port'] = input()
        print(f'database:')
        db_config['connection_info']['database'] = input()
        print(f'PostgreSQL database setup complete.')
    else:
        raise ReferenceError("Unrecognize string or database type not allowed.")
    with open(config_location, 'w+') as configfile:
        db_config.write(configfile)


if db_config.get('general', 'db_type') == 'sqlite':
    database_location = path.join(base_folder, 'ezreal_core_schema.db')
    db_url = db_config.get('general', 'db_type') + ':///{}'.format(database_location)
elif db_config.get('general', 'db_type') == 'postgresql':
    db_url = db_config.get('general', 'db_type') + '://' + db_config.get('connection_info', 'username') + ':' \
             + db_config.get('connection_info', 'password') + '@' + db_config.get('connection_info', 'host') \
             + ':' + db_config.get('connection_info', 'port') + '/' + db_config.get('connection_info', 'database')

engine = sqlalchemy.create_engine(db_url)

# Creating an easy access function
get_session = orm.sessionmaker(bind=engine)

# Defining the function to call at the end of the sqlite initialization
def initialize_sql():
    Base.metadata.create_all(engine)


"""A setuptools based setup module.
See:
https://packaging.python.org/guides/distributing-packages-using-setuptools/
https://github.com/pypa/sampleproject
"""
from setuptools import setup, find_packages
from os import path

here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()
setup(
    name='ezreal',
    version='1.0a2',
    description='An application of services.',
    long_description='Ezreal is a service distributor. '
                     'It exploits different tools and framework around the league of legends environment and gathers '
                     'their functionalities in order to serve functions to feed interfaces. '
                     'Its initial design serves the EzrealBot interface, a bot for discord. ',
    long_description_content_type='text/markdown',
    url='https://github.com/maximeheliot/ezreal',
    author='An aspiring data scientist enthousiast',
    author_email='maxime.heliotpro@example.com',
    classifiers=[
        'Development Status :: 3 - Alpha',
        "Intended Audience :: Customer Service",
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.8',
    ],
    keywords='services, framework, tool, leagueoflegends, statistics',
    packages=["ezreal", "ezreal/core", "ezreal/utils"],
    python_requires='>=3.7, <4',
    install_requires=['cassiopeia',
                      'SQLAlchemy'],
    project_urls={  # Optional
        'Bug Reports': 'https://github.com/maximeheliot/ezreal/issues',
        'Funding': 'https://donate.pypi.org',
        'Source': 'https://github.com/pypa/ezreal/',
    },
)